@@ -566,7 +566,7 @@ module MCollective
           # limit method then pass in the limit thus minimizing the amount
           # of work we do in the discover phase and speeding it up significantly
           filter = @filter.merge({'collective' => @collective})
-          if @limit_method == :first and @limit_targets.is_a?(Fixnum)
+          if @limit_method == :first and @limit_targets.is_a?(Integer)
             @discovered_agents = @client.discover(filter, discovery_timeout, @limit_targets)
           else
             @discovered_agents = @client.discover(filter, discovery_timeout)
@@ -739,8 +739,13 @@ module MCollective
       end
 
       def rpc_result_from_reply(agent, action, reply)
-        Result.new(agent, action, {:sender => reply[:senderid], :statuscode => reply[:body][:statuscode],
-                                   :statusmsg => reply[:body][:statusmsg], :data => reply[:body][:data]})
+        senderid = reply.include?("senderid") ? reply["senderid"] : reply[:senderid]
+        body = reply.include?("body") ? reply["body"] : reply[:body]
+        s_code = body.include?("statuscode") ? body["statuscode"] : body[:statuscode]
+        s_msg = body.include?("statusmsg") ? body["statusmsg"] : body[:statusmsg]
+        data = body.include?("data") ? body["data"] : body[:data]
+
+        Result.new(agent, action, {:sender => senderid, :statuscode => s_code, :statusmsg => s_msg, :data => data})
       end
 
       # for requests that do not care for results just
@@ -995,9 +1000,9 @@ module MCollective
         result = rpc_result_from_reply(@agent, action, resp)
         aggregate = aggregate_reply(result, aggregate) if aggregate
 
-        if resp[:body][:statuscode] == 0 || resp[:body][:statuscode] == 1
-          @stats.ok if resp[:body][:statuscode] == 0
-          @stats.fail if resp[:body][:statuscode] == 1
+        if result[:statuscode] == 0 || result[:statuscode] == 1
+          @stats.ok if result[:statuscode] == 0
+          @stats.fail if result[:statuscode] == 1
         else
           @stats.fail
         end
@@ -1015,8 +1020,8 @@ module MCollective
         result = rpc_result_from_reply(@agent, action, resp)
         aggregate = aggregate_reply(result, aggregate) if aggregate
 
-        @stats.ok if resp[:body][:statuscode] == 0
-        @stats.fail if resp[:body][:statuscode] != 0
+        @stats.ok if result[:statuscode] == 0
+        @stats.fail if result[:statuscode] != 0
         @stats.time_block_execution :start
 
         case block.arity
